from pathlib import Path

TEMPLATES_DIR = Path(__file__).parent / "templates"

TEMPLATES = {
    "etl": {
        "description": "Extract-Transform-Load pipeline",
        "dir": "etl",
    },
    "ml": {
        "description": "Machine learning pipeline",
        "dir": "ml",
    },
    "utility": {
        "description": "Utility / helper library",
        "dir": "utility",
    },
}

STORAGE_PATHS = {
    "uc": "dbfs:/Volumes/catalog/schema/volume",
    "dbfs": "dbfs:/FileStore/wheels",
    "s3": "s3://bucket/wheels",
    "adls": "abfss://container@storageaccount.dfs.core.windows.net/wheels",
}

